@@ -73,7 +73,7 @@ def test_context_api_transform_validation_additional_fields():
 
 
 def test_context_api_transform_extensions():
-    """Expected result for extensions after trasform:
+    """Expected result for extensions after transform:
 
     'extensions': {
         'extended_schema_url': 'extended_release_schema.json',
@@ -149,7 +149,7 @@ def test_context_api_transform_extensions():
 
 
 def test_context_api_transform_deprecations():
-    """Expected result for deprecated field after trasform:
+    """Expected result for deprecated field after transform:
 
     'deprecated_fields': [
         {"field": "a", "paths": ["path_to_a/0/a", "path_to_a/1/a"], "explanation": ["1.1", "description_a"]},
